referrerpolicy=no-referrer-when-downgrade

read_and_write_big_value

Function read_and_write_big_value 

pub fn read_and_write_big_value<T: Config>()
Reads a key and writes a big value under this key.

At genesis this key is empty and thus, will only be set in consequent blocks.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::read_and_write_big_value.