referrerpolicy=no-referrer-when-downgrade

read_and_write_child_tries

Function read_and_write_child_tries 

pub fn read_and_write_child_tries<T: Config>()
A dispatchable that first reads two values from two different child tries, asserts they are the expected values (if the values exist in the state) and then writes two different values to these child tries.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::read_and_write_child_tries.