pub fn set_custom_validation_head_data<T: Config>(custom_header: Vec<u8>)Expand description
A test dispatchable for setting a custom head data in validate_block.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_custom_validation_head_data.