pub fn set_inherent_weight_consume<T: Config>(weight: Weight)Expand description
Set the weight to be consumed by the next inherent call.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::set_inherent_weight_consume.